@@ -64,6 +64,8 @@ PUBLIC_CHAINS = {
     42: "Kovan",
     77: "Sokol",
     100: "xDai",
+    137: "Polygon/Mainnet",
+    80001: "Polygon/Mumbai"
 }
 
 LOCAL_CHAINS = {
@@ -84,7 +86,10 @@ POA_CHAINS = {
 class EthereumClient:
     is_local = False
 
+    # These two are used by Infura
     GETH = 'Geth'
+    BOR = 'bor'
+
     PARITY = 'Parity'
     ALT_PARITY = 'Parity-Ethereum'
     GANACHE = 'EthereumJS TestRPC'
@@ -162,11 +167,13 @@ class EthereumClient:
         Parity  -> 'Parity-Ethereum/v2.5.1-beta-e0141f8-20190510/x86_64-linux-gnu/rustc1.34.1'
         Ganache -> 'EthereumJS TestRPC/v2.1.5/ethereum-js'
         PyEVM   -> 'EthereumTester/0.1.0b39/linux/python3.6.7'
+        Bor     -> 'bor/v0.2.13-beta2-c227a072/linux-amd64/go1.17.5'
         """
         clients = {
 
             # Geth
             cls.GETH: GethClient,
+            cls.BOR: BorClient,
 
             # Parity
             cls.PARITY: ParityClient,
@@ -386,6 +393,9 @@ class EthereumClient:
         now = highest_block['timestamp']
         return now
 
+    def get_block(self, block_identifier):
+        return self.w3.eth.getBlock(block_identifier)
+
     def _has_latest_block(self) -> bool:
         # TODO: Investigate using `web3.middleware.make_stalecheck_middleware` #2060
         # check that our local chain data is up to date
@@ -458,6 +468,10 @@ class GethClient(EthereumClient):
         return self.w3.geth.personal.list_wallets()
 
 
+class BorClient(GethClient):
+    """Geth to Bor adapter"""
+
+
 class ParityClient(EthereumClient):
 
     @property
@@ -510,7 +524,7 @@ class EthereumTesterClient(EthereumClient):
     is_local = True
 
     def unlock_account(self, account, password, duration: int = None) -> bool:
-        """Returns True if the testing backend keyring has control of the given address."""
+        """Returns True if the testing backend keystore has control of the given address."""
         account = to_checksum_address(account)
         keystore_accounts = self.w3.provider.ethereum_tester.get_accounts()
         if account in keystore_accounts:
@@ -521,7 +535,7 @@ class EthereumTesterClient(EthereumClient):
                                                                    unlock_seconds=duration)
 
     def lock_account(self, account) -> bool:
-        """Returns True if the testing backend keyring has control of the given address."""
+        """Returns True if the testing backend keystore has control of the given address."""
         account = to_canonical_address(account)
         keystore_accounts = self.w3.provider.ethereum_tester.backend.get_accounts()
         if account in keystore_accounts:
