@@ -31,25 +31,25 @@ class ProviderError(Exception):
     pass
 
 
-def _get_IPC_provider(provider_uri) -> BaseProvider:
-    uri_breakdown = urlparse(provider_uri)
+def _get_IPC_provider(eth_provider_uri) -> BaseProvider:
+    uri_breakdown = urlparse(eth_provider_uri)
     from nucypher.blockchain.eth.interfaces import BlockchainInterface
     return IPCProvider(ipc_path=uri_breakdown.path,
                        timeout=BlockchainInterface.TIMEOUT,
                        request_kwargs={'timeout': BlockchainInterface.TIMEOUT})
 
 
-def _get_HTTP_provider(provider_uri) -> BaseProvider:
+def _get_HTTP_provider(eth_provider_uri) -> BaseProvider:
     from nucypher.blockchain.eth.interfaces import BlockchainInterface
-    return HTTPProvider(endpoint_uri=provider_uri, request_kwargs={'timeout': BlockchainInterface.TIMEOUT})
+    return HTTPProvider(endpoint_uri=eth_provider_uri, request_kwargs={'timeout': BlockchainInterface.TIMEOUT})
 
 
-def _get_websocket_provider(provider_uri) -> BaseProvider:
+def _get_websocket_provider(eth_provider_uri) -> BaseProvider:
     from nucypher.blockchain.eth.interfaces import BlockchainInterface
-    return WebsocketProvider(endpoint_uri=provider_uri, websocket_kwargs={'timeout': BlockchainInterface.TIMEOUT})
+    return WebsocketProvider(endpoint_uri=eth_provider_uri, websocket_kwargs={'timeout': BlockchainInterface.TIMEOUT})
 
 
-def _get_auto_provider(provider_uri) -> BaseProvider:
+def _get_auto_provider(eth_provider_uri) -> BaseProvider:
     from web3.auto import w3
     # how-automated-detection-works: https://web3py.readthedocs.io/en/latest/providers.html
     connected = w3.isConnected()
@@ -78,7 +78,7 @@ def _get_ethereum_tester(test_backend: Union[PyEVMBackend, MockBackend]) -> Ethe
     return provider
 
 
-def _get_pyevm_test_provider(provider_uri) -> BaseProvider:
+def _get_pyevm_test_provider(eth_provider_uri) -> BaseProvider:
     """ Test provider entry-point"""
     # https://github.com/ethereum/eth-tester#pyevm-experimental
     pyevm_eth_tester = _get_pyevm_test_backend()
@@ -86,13 +86,13 @@ def _get_pyevm_test_provider(provider_uri) -> BaseProvider:
     return provider
 
 
-def _get_mock_test_provider(provider_uri) -> BaseProvider:
+def _get_mock_test_provider(eth_provider_uri) -> BaseProvider:
     # https://github.com/ethereum/eth-tester#mockbackend
     mock_backend = MockBackend()
     provider = _get_ethereum_tester(test_backend=mock_backend)
     return provider
 
 
-def _get_tester_ganache(provider_uri=None) -> BaseProvider:
-    endpoint_uri = provider_uri or 'http://localhost:7545'
+def _get_tester_ganache(eth_provider_uri=None) -> BaseProvider:
+    endpoint_uri = eth_provider_uri or 'http://localhost:7545'
     return HTTPProvider(endpoint_uri=endpoint_uri)
