@@ -75,16 +75,6 @@ the Encryptor.
 """
 
 
-MOE_BANNER = r"""
- _______               
-|   |   |.-----..-----.
-|       ||  _  ||  -__|
-|__|_|__||_____||_____|
-
-the Monitor.
-"""
-
-
 URSULA_BANNER = r'''
 
 
@@ -104,18 +94,6 @@ the Untrusted Re-Encryption Proxy.
 {}
 '''
 
-FELIX_BANNER = r"""
-
-'||''''|        '||`            
- ||  .           ||   ''        
- ||''|   .|''|,  ||   ||  \\  //
- ||      ||..||  ||   ||    ><  
-.||.     `|...  .||. .||. //  \\
-
-
-the Unlicensed Faucet Plumber
-{}
-"""
 
 STAKEHOLDER_BANNER = r"""
  ____    __            __                      
@@ -128,15 +106,3 @@ STAKEHOLDER_BANNER = r"""
    
 The Holder of Stakes.                                      
 """
-
-
-WORKLOCK_BANNER = r"""
- _    _               _     _                   _    
-| |  | |             | |   | |                 | |   
-| |  | |  ___   _ __ | | __| |      ___    ___ | | __
-| |/\| | / _ \ | '__|| |/ /| |     / _ \  / __|| |/ /
-\  /\  /| (_) || |   |   < | |____| (_) || (__ |   < 
- \/  \/  \___/ |_|   |_|\_\\_____/ \___/  \___||_|\_\
-
-══ {} ══                                                   
-"""
