@@ -14,14 +14,16 @@
  You should have received a copy of the GNU Affero General Public License
  along with nucypher.  If not, see <https://www.gnu.org/licenses/>.
 """
+
+
 import glob
 import json
 from json.decoder import JSONDecodeError
+from pathlib import Path
 from typing import Optional, Type, List
 
 import click
 
-from nucypher.characters.control.emitters import StdoutEmitter
 from nucypher.characters.lawful import Ursula
 from nucypher.cli.actions.confirm import confirm_destroy_configuration
 from nucypher.cli.literature import (
@@ -35,11 +37,11 @@ from nucypher.cli.literature import (
     COLLECT_URSULA_IPV4_ADDRESS,
     CONFIRM_URSULA_IPV4_ADDRESS
 )
-from nucypher.cli.types import WORKER_IP
+from nucypher.cli.types import OPERATOR_IP
 from nucypher.config.base import CharacterConfiguration
-from nucypher.config.characters import StakeHolderConfiguration
 from nucypher.config.constants import DEFAULT_CONFIG_ROOT
-from nucypher.utilities.networking import InvalidWorkerIP, validate_worker_ip
+from nucypher.control.emitters import StdoutEmitter
+from nucypher.utilities.networking import InvalidOperatorIP, validate_operator_ip
 from nucypher.utilities.networking import determine_external_ip_address, UnknownIPAddress
 
 
@@ -50,25 +52,26 @@ def forget(emitter: StdoutEmitter, configuration: CharacterConfiguration) -> Non
     emitter.message(SUCCESSFUL_FORGET_NODES, color='red')
 
 
-def get_config_filepaths(config_class: Type[CharacterConfiguration], config_root: str = None) -> List:
+def get_config_filepaths(config_class: Type[CharacterConfiguration], config_root: Optional[Path] = None) -> List:
     #
     # Scrape disk for configuration files
     #
     config_root = config_root or DEFAULT_CONFIG_ROOT
-    default_config_file = glob.glob(config_class.default_filepath(config_root=config_root))
+    default_config_file = glob.glob(str(config_class.default_filepath(config_root=config_root)))
 
     # updated glob pattern for secondary configuration files accommodates for:
     # 1. configuration files with "0x..." checksum address as suffix - including older ursula config files
     # 2. newer (ursula) configuration files which use signing_pub_key[:8] as hex as the suffix
-    glob_pattern = f'{config_root}/{config_class.NAME}-[0-9a-fA-F]*.{config_class._CONFIG_FILE_EXTENSION}'
+    glob_pattern = f'{config_root.absolute()}/{config_class.NAME}-[0-9a-fA-F]*.{config_class._CONFIG_FILE_EXTENSION}'
 
     secondary_config_files = sorted(glob.glob(glob_pattern))  # sort list to make order deterministic
     config_files = [*default_config_file, *secondary_config_files]
+    config_files = [Path(f) for f in config_files]
     return config_files
 
 
 def get_or_update_configuration(emitter: StdoutEmitter,
-                                filepath: str,
+                                filepath: Path,
                                 config_class: Type[CharacterConfiguration],
                                 updates: Optional[dict] = None) -> None:
     """
@@ -104,20 +107,18 @@ def destroy_configuration(emitter: StdoutEmitter,
 
 def handle_missing_configuration_file(character_config_class: Type[CharacterConfiguration],
                                       init_command_hint: str = None,
-                                      config_file: str = None) -> None:
+                                      config_file: Optional[Path] = None) -> None:
     """Display a message explaining there is no configuration file to use and abort the current operation."""
     config_file_location = config_file or character_config_class.default_filepath()
     init_command = init_command_hint or f"{character_config_class.NAME} init"
     name = character_config_class.NAME.capitalize()
-    if name == StakeHolderConfiguration.NAME.capitalize():
-        init_command = 'stake init-stakeholder'
     message = MISSING_CONFIGURATION_FILE.format(name=name, init_command=init_command)
-    raise click.FileError(filename=config_file_location, hint=message)
+    raise click.FileError(filename=str(config_file_location.absolute()), hint=message)
 
 
 def handle_invalid_configuration_file(emitter: StdoutEmitter,
                                       config_class: Type[CharacterConfiguration],
-                                      filepath: str) -> None:
+                                      filepath: Path) -> None:
     """
     Attempt to deserialize a config file that is not a valid nucypher character configuration
     as a means of user-friendly debugging. :-)  I hope this helps!
@@ -135,7 +136,7 @@ def handle_invalid_configuration_file(emitter: StdoutEmitter,
         raise  # crash :-(
 
 
-def collect_worker_ip_address(emitter: StdoutEmitter, network: str, force: bool = False) -> str:
+def collect_operator_ip_address(emitter: StdoutEmitter, network: str, force: bool = False) -> str:
 
     # From node swarm
     try:
@@ -146,14 +147,14 @@ def collect_worker_ip_address(emitter: StdoutEmitter, network: str, force: bool
         if force:
             raise
         emitter.message('Cannot automatically determine external IP address - input required')
-        ip = click.prompt(COLLECT_URSULA_IPV4_ADDRESS, type=WORKER_IP)
+        ip = click.prompt(COLLECT_URSULA_IPV4_ADDRESS, type=OPERATOR_IP)
 
     # Confirmation
     if not force:
         if not click.confirm(CONFIRM_URSULA_IPV4_ADDRESS.format(rest_host=ip)):
-            ip = click.prompt(COLLECT_URSULA_IPV4_ADDRESS, type=WORKER_IP)
+            ip = click.prompt(COLLECT_URSULA_IPV4_ADDRESS, type=OPERATOR_IP)
 
-    validate_worker_ip(worker_ip=ip)
+    validate_operator_ip(ip=ip)
     return ip
 
 
@@ -170,9 +171,9 @@ def perform_startup_ip_check(emitter: StdoutEmitter, ursula: Ursula, force: bool
         return  # TODO: crash, or not to crash... that is the question
     rest_host = ursula.rest_interface.host
     try:
-        validate_worker_ip(worker_ip=rest_host)
-    except InvalidWorkerIP:
-        message = f'{rest_host} is not a valid or permitted worker IP address.  Set the correct external IP then try again\n' \
+        validate_operator_ip(ip=rest_host)
+    except InvalidOperatorIP:
+        message = f'{rest_host} is not a valid or permitted operator IP address.  Set the correct external IP then try again\n' \
                   f'automatic configuration -> nucypher ursula config ip-address\n' \
                   f'manual configuration    -> nucypher ursula config --rest-host <IP ADDRESS>'
         emitter.message(message)
@@ -180,7 +181,7 @@ def perform_startup_ip_check(emitter: StdoutEmitter, ursula: Ursula, force: bool
 
     ip_mismatch = external_ip != rest_host
     if ip_mismatch and not force:
-        error = f'\nX External IP address ({external_ip}) does not match configuration ({ursula.rest_interface.host}).\n'
+        error = f'\nx External IP address ({external_ip}) does not match configuration ({ursula.rest_interface.host}).\n'
         hint = f"Run 'nucypher ursula config ip-address' to reconfigure the IP address then try " \
                f"again or use --no-ip-checkup to bypass this check (not recommended).\n"
         emitter.message(error, color='red')
