@@ -18,6 +18,7 @@
 
 
 from collections import deque
+from pathlib import Path
 
 import maya
 import os
@@ -92,16 +93,6 @@ class UrsulaCommandProtocol(LineReceiver):
         from nucypher.cli.painting.nodes import paint_known_nodes
         paint_known_nodes(emitter=self.emitter, ursula=self.ursula)
 
-    def paintStakes(self):
-        """
-        Display a list of all active stakes.
-        """
-        if self.ursula.stakes:
-            from nucypher.cli.painting.staking import paint_stakes
-            paint_stakes(self.emitter, stakes=self.ursula.stakes)
-        else:
-            self.emitter.echo("No active stakes.")
-
     def paintStatus(self):
         """
         Display the current status of the attached Ursula node.
@@ -175,7 +166,7 @@ class JSONRPCLineReceiver(LineReceiver):
 
     encoding = 'utf-8'
     delimiter = os.linesep.encode(encoding=encoding)
-    __ipc_endpoint = "/tmp/nucypher.ipc"
+    __ipc_endpoint = Path("/tmp/nucypher.ipc")
 
     class IPCWriter(StandardIO):
         pass
@@ -206,12 +197,12 @@ class JSONRPCLineReceiver(LineReceiver):
         # Hookup the IPC endpoint file
         self.transport.write = self.__ipc_writer
 
-        self.log.info(f"JSON RPC-IPC endpoint opened at {self.__ipc_endpoint}."
+        self.log.info(f"JSON RPC-IPC endpoint opened at {self.__ipc_endpoint.absolute()}."
                       f" Listening for messages.")  # TODO
 
     def connectionLost(self, reason=connectionDone) -> None:
         self.__ipc_fd.close()
-        os.remove(self.__ipc_endpoint)
+        self.__ipc_endpoint.unlink()
 
         self.log.info("JSON RPC-IPC Endpoint Closed.")  # TODO
 
