@@ -15,27 +15,23 @@ You should have received a copy of the GNU Affero General Public License
 along with nucypher.  If not, see <https://www.gnu.org/licenses/>.
 """
 
-from pathlib import Path
-
-import OpenSSL
 import binascii
-import os
 import tempfile
 from abc import ABC, abstractmethod
+from pathlib import Path
+from typing import Any, Optional, Set, Union
 
-from bytestring_splitter import BytestringSplittingError
+import OpenSSL
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives.serialization import Encoding
-from cryptography.x509 import Certificate, NameOID
-from eth_utils import is_checksum_address
-from typing import Any, Callable, Set, Tuple, Union
+from cryptography.x509 import Certificate
 
-from nucypher.acumen.nicknames import Nickname
 from nucypher.blockchain.eth.decorators import validate_checksum_address
 from nucypher.blockchain.eth.registry import BaseContractRegistry
 from nucypher.config.constants import DEFAULT_CONFIG_ROOT
-from nucypher.crypto.api import read_certificate_pseudonym, InvalidNodeCertificate
+from nucypher.config.util import cast_paths_from
+from nucypher.crypto.signing import SignatureStamp
 from nucypher.utilities.logging import Logger
 
 
@@ -53,7 +49,7 @@ class NodeStorage(ABC):
         pass
 
     def __init__(self,
-                 federated_only: bool,  # TODO# 466
+                 federated_only: bool = False,  # TODO# 466
                  character_class=None,
                  registry: BaseContractRegistry = None,
                  ) -> None:
@@ -71,9 +67,6 @@ class NodeStorage(ABC):
     def __setitem__(self, key, value):
         return self.store_node_metadata(node=value)
 
-    def __delitem__(self, key):
-        self.remove(checksum_address=key)
-
     def __iter__(self):
         return self.all(federated_only=self.federated_only)
 
@@ -97,61 +90,42 @@ class NodeStorage(ABC):
         return common_name_from_cert
 
     def _write_tls_certificate(self,
+                               port: int,  # used to avoid duplicate certs with the same IP
                                certificate: Certificate,
-                               host: str = None,
-                               force: bool = True) -> str:
+                               force: bool = True) -> Path:
 
         # Read
         x509 = OpenSSL.crypto.X509.from_cryptography(certificate)
         subject_components = x509.get_subject().get_components()
         common_name_as_bytes = subject_components[0][1]
         common_name_on_certificate = common_name_as_bytes.decode()
-        if not host:
-            host = common_name_on_certificate
+        host = common_name_on_certificate
 
-        try:
-            pseudonym = certificate.subject.get_attributes_for_oid(NameOID.PSEUDONYM)[0]
-        except IndexError:
-            raise InvalidNodeCertificate(f"Missing checksum address on certificate for host '{host}'. "
-                                         f"Does this certificate belong to an Ursula?")
-        else:
-            checksum_address = pseudonym.value
-
-        if not is_checksum_address(checksum_address):
-            raise InvalidNodeCertificate("Invalid certificate wallet address encountered: {}".format(checksum_address))
-
-        # Validate
-        # TODO: It's better for us to have checked this a while ago so that this situation is impossible.  #443
-        if host and (host != common_name_on_certificate):
-            raise ValueError(f"You passed a hostname ('{host}') that does not match the certificate's common name.")
-
-        certificate_filepath = self.generate_certificate_filepath(checksum_address=checksum_address)
-        certificate_already_exists = os.path.isfile(certificate_filepath)
+        certificate_filepath = self.generate_certificate_filepath(host=host, port=port)
+        certificate_already_exists = certificate_filepath.is_file()
         if force is False and certificate_already_exists:
             raise FileExistsError('A TLS certificate already exists at {}.'.format(certificate_filepath))
 
         # Write
-        os.makedirs(os.path.dirname(certificate_filepath), exist_ok=True)
+        certificate_filepath.parent.mkdir(parents=True, exist_ok=True)
         with open(certificate_filepath, 'wb') as certificate_file:
             public_pem_bytes = certificate.public_bytes(self.TLS_CERTIFICATE_ENCODING)
             certificate_file.write(public_pem_bytes)
 
-        nickname = Nickname.from_seed(checksum_address)
-        self.log.debug(f"Saved TLS certificate for {nickname} {checksum_address}: {certificate_filepath}")
-
+        self.log.debug(f"Saved TLS certificate for {host} to {certificate_filepath}")
         return certificate_filepath
 
     @abstractmethod
-    def store_node_certificate(self, certificate: Certificate) -> str:
+    def store_node_certificate(self, certificate: Certificate, port: int) -> Path:
         raise NotImplementedError
 
     @abstractmethod
-    def store_node_metadata(self, node, filepath: str = None) -> str:
+    def store_node_metadata(self, node, filepath: Optional[Path] = None) -> Path:
         """Save a single node's metadata and tls certificate"""
         raise NotImplementedError
 
     @abstractmethod
-    def generate_certificate_filepath(self, checksum_address: str) -> str:
+    def generate_certificate_filepath(self, host: str, port: int) -> Path:
         raise NotImplementedError
 
     @abstractmethod
@@ -179,11 +153,6 @@ class NodeStorage(ABC):
         """Retrieve a single stored node"""
         raise NotImplementedError
 
-    @abstractmethod
-    def remove(self, checksum_address: str) -> bool:
-        """Remove a single stored node"""
-        raise NotImplementedError
-
     @abstractmethod
     def clear(self) -> bool:
         """Remove all stored nodes"""
@@ -194,14 +163,14 @@ class ForgetfulNodeStorage(NodeStorage):
     _name = ':memory:'
     __base_prefix = "nucypher-tmp-certs-"
 
-    def __init__(self, parent_dir: str = None, *args, **kwargs) -> None:
+    def __init__(self, parent_dir: Optional[Path] = None, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.__metadata = dict()
 
         # Certificates
         self.__certificates = dict()
         self.__temporary_certificates = list()
-        self._temp_certificates_dir = tempfile.mkdtemp(prefix=self.__base_prefix, dir=parent_dir)
+        self._temp_certificates_dir = Path(tempfile.mkdtemp(prefix=self.__base_prefix, dir=parent_dir))
 
     @property
     def source(self) -> str:
@@ -215,58 +184,42 @@ class ForgetfulNodeStorage(NodeStorage):
     def get(self,
             federated_only: bool,
             host: str = None,
-            checksum_address: str = None,
+            stamp: SignatureStamp = None,
             certificate_only: bool = False):
 
-        if not bool(checksum_address) ^ bool(host):
-            message = "Either pass checksum_address or host; Not both. Got ({} {})".format(checksum_address, host)
+        if not bool(stamp) ^ bool(host):
+            message = "Either pass stamp or host; Not both. Got ({} {})".format(stamp, host)
             raise ValueError(message)
 
         if certificate_only is True:
             try:
-                return self.__certificates[checksum_address or host]
+                return self.__certificates[stamp or host]
             except KeyError:
                 raise self.UnknownNode
         else:
             try:
-                return self.__metadata[checksum_address or host]
+                return self.__metadata[stamp or host]
             except KeyError:
                 raise self.UnknownNode
 
     def forget(self) -> bool:
         for temp_certificate in self.__temporary_certificates:
-            os.remove(temp_certificate)
+            temp_certificate.unlink()
         return len(self.__temporary_certificates) == 0
 
-    def store_node_certificate(self, certificate: Certificate):
-        checksum_address = read_certificate_pseudonym(certificate=certificate)
-        self.__certificates[checksum_address] = certificate
-        filepath = self._write_tls_certificate(certificate=certificate)
+    def store_node_certificate(self, certificate: Certificate, port: int) -> Path:
+        filepath = self._write_tls_certificate(certificate=certificate, port=port)
         return filepath
 
-    def store_node_metadata(self, node, filepath: str = None):
-        self.__metadata[node.checksum_address] = node
-        return self.__metadata[node.checksum_address]
+    def store_node_metadata(self, node, filepath: Optional[Path] = None) -> bytes:
+        self.__metadata[node.stamp] = node
+        return self.__metadata[node.stamp]
 
-    @validate_checksum_address
-    def generate_certificate_filepath(self, checksum_address: str) -> str:
-        filename = '{}.pem'.format(checksum_address)
-        filepath = os.path.join(self._temp_certificates_dir, filename)
+    def generate_certificate_filepath(self, host: str, port: int) -> Path:
+        filename = f'{host}:{port}.pem'
+        filepath = self._temp_certificates_dir / filename
         return filepath
 
-    @validate_checksum_address
-    def remove(self,
-               checksum_address: str,
-               metadata: bool = True,
-               certificate: bool = True
-               ) -> Tuple[bool, str]:
-
-        if metadata is True:
-            del self.__metadata[checksum_address]
-        if certificate is True:
-            del self.__certificates[checksum_address]
-        return True, checksum_address
-
     def clear(self, metadata: bool = True, certificates: bool = True) -> None:
         """Forget all stored nodes and certificates"""
         if metadata is True:
@@ -301,10 +254,10 @@ class LocalFileBasedNodeStorage(NodeStorage):
         """Node metadata is corrupt or not possible to parse"""
 
     def __init__(self,
-                 config_root: str = None,
-                 storage_root: str = None,
-                 metadata_dir: str = None,
-                 certificates_dir: str = None,
+                 config_root: Optional[Path] = None,
+                 storage_root: Optional[Path] = None,
+                 metadata_dir: Optional[Path] = None,
+                 certificates_dir: Optional[Path] = None,
                  *args, **kwargs
                  ) -> None:
 
@@ -317,7 +270,7 @@ class LocalFileBasedNodeStorage(NodeStorage):
         self._cache_storage_filepaths(config_root=config_root)
 
     @property
-    def source(self) -> str:
+    def source(self) -> Path:
         """Human readable source string"""
         return self.root_dir
 
@@ -328,14 +281,14 @@ class LocalFileBasedNodeStorage(NodeStorage):
         return encoded_node
 
     @staticmethod
-    def _generate_storage_filepaths(config_root: str = None,
-                                    storage_root: str = None,
-                                    metadata_dir: str = None,
-                                    certificates_dir: str = None):
+    def _generate_storage_filepaths(config_root: Optional[Path] = None,
+                                    storage_root: Optional[Path] = None,
+                                    metadata_dir: Optional[Path] = None,
+                                    certificates_dir: Optional[Path] = None):
 
-        storage_root = storage_root or os.path.join(config_root or DEFAULT_CONFIG_ROOT, 'known_nodes')
-        metadata_dir = metadata_dir or os.path.join(storage_root, 'metadata')
-        certificates_dir = certificates_dir or os.path.join(storage_root, 'certificates')
+        storage_root = storage_root or ((config_root or DEFAULT_CONFIG_ROOT) / 'known_nodes')
+        metadata_dir = metadata_dir or storage_root / 'metadata'
+        certificates_dir = certificates_dir or storage_root / 'certificates'
 
         payload = {'storage_root': storage_root,
                    'metadata_dir': metadata_dir,
@@ -343,7 +296,7 @@ class LocalFileBasedNodeStorage(NodeStorage):
 
         return payload
 
-    def _cache_storage_filepaths(self, config_root: str = None):
+    def _cache_storage_filepaths(self, config_root: Optional[Path] = None):
         filepaths = self._generate_storage_filepaths(config_root=config_root,
                                                      storage_root=self.root_dir,
                                                      metadata_dir=self.metadata_dir,
@@ -357,34 +310,23 @@ class LocalFileBasedNodeStorage(NodeStorage):
     #
 
     @validate_checksum_address
-    def __get_certificate_filename(self, checksum_address: str):
-        return '{}.{}'.format(checksum_address, Encoding.PEM.name.lower())
+    def __get_certificate_filename(self, host: str, port: int) -> str:
+        return f'{host}:{port}.{Encoding.PEM.name.lower()}'
 
-    def __get_certificate_filepath(self, certificate_filename: str) -> str:
-        return os.path.join(self.certificates_dir, certificate_filename)
+    def __get_certificate_filepath(self, certificate_filename: str) -> Path:
+        return self.certificates_dir / certificate_filename
 
-    @validate_checksum_address
-    def generate_certificate_filepath(self, checksum_address: str) -> str:
-        certificate_filename = self.__get_certificate_filename(checksum_address)
+    def generate_certificate_filepath(self, host: str, port: int) -> Path:
+        certificate_filename = self.__get_certificate_filename(host=host, port=port)
         certificate_filepath = self.__get_certificate_filepath(certificate_filename=certificate_filename)
         return certificate_filepath
 
     @validate_checksum_address
-    def __read_node_tls_certificate(self, filepath: str = None, checksum_address: str = None) -> Certificate:
+    def __read_node_tls_certificate(self, filepath: Optional[Path] = None) -> Certificate:
         """Deserialize an X509 certificate from a filepath"""
-        if not bool(filepath) ^ bool(checksum_address):
-            raise ValueError("Either pass filepath or checksum_address; Not both.")
-
-        if not filepath and checksum_address is not None:
-            filepath = self.generate_certificate_filepath(checksum_address)
-
         try:
             with open(filepath, 'rb') as certificate_file:
-                certificate = x509.load_pem_x509_certificate(certificate_file.read(), backend=default_backend())
-                # Sanity check:
-                # Validate the checksum address inside the cert as a consistency check against
-                # nodes that may have been altered on the disk somehow.
-                read_certificate_pseudonym(certificate=certificate)
+                certificate = x509.load_der_x509_certificate(certificate_file.read(), backend=default_backend())
                 return certificate
         except FileNotFoundError:
             raise FileNotFoundError("No SSL certificate found at {}".format(filepath))
@@ -393,13 +335,16 @@ class LocalFileBasedNodeStorage(NodeStorage):
     # Metadata
     #
 
-    @validate_checksum_address
-    def __generate_metadata_filepath(self, checksum_address: str, metadata_dir: str = None) -> str:
-        metadata_path = os.path.join(metadata_dir or self.metadata_dir,
-                                     self.__METADATA_FILENAME_TEMPLATE.format(checksum_address))
+    def __generate_metadata_filepath(self, stamp: Union[SignatureStamp, bytes, str], metadata_dir: Optional[Path] = None) -> Path:
+        if isinstance(stamp, SignatureStamp):
+            stamp = bytes(stamp)
+        if isinstance(stamp, str):
+            stamp = bytes.fromhex(stamp)
+        stamp = stamp.hex()
+        metadata_path = metadata_dir or self.metadata_dir / self.__METADATA_FILENAME_TEMPLATE.format(stamp)
         return metadata_path
 
-    def __read_metadata(self, filepath: str):
+    def __read_metadata(self, filepath: Path):
 
         from nucypher.characters.lawful import Ursula
 
@@ -407,18 +352,18 @@ class LocalFileBasedNodeStorage(NodeStorage):
             with open(filepath, "rb") as seed_file:
                 seed_file.seek(0)
                 node_bytes = self.decode_node_bytes(seed_file.read())
-                node = Ursula.from_bytes(node_bytes, fail_fast=True)
+                node = Ursula.from_metadata_bytes(node_bytes)
         except FileNotFoundError:
             raise self.NoNodeMetadataFileFound
-        except (BytestringSplittingError, Ursula.UnexpectedVersion):
-            raise self.InvalidNodeMetadata
+        except Exception as e:
+            raise self.InvalidNodeMetadata from e
 
         return node
 
-    def __write_metadata(self, filepath: str, node):
-        os.makedirs(os.path.dirname(filepath), exist_ok=True)
+    def __write_metadata(self, filepath: Path, node):
+        filepath.parent.mkdir(parents=True, exist_ok=True)
         with open(filepath, "wb") as f:
-            f.write(self.encode_node_bytes(bytes(node)))
+            f.write(self.encode_node_bytes(bytes(node.metadata())))
         self.log.info("Wrote new node metadata to filesystem {}".format(filepath))
         return filepath
 
@@ -426,13 +371,13 @@ class LocalFileBasedNodeStorage(NodeStorage):
     # API
     #
     def all(self, federated_only: bool, certificates_only: bool = False) -> Set[Union[Any, Certificate]]:
-        filenames = os.listdir(self.certificates_dir if certificates_only else self.metadata_dir)
+        filenames = list((self.certificates_dir if certificates_only else self.metadata_dir).iterdir())
         self.log.info("Found {} known node metadata files at {}".format(len(filenames), self.metadata_dir))
 
         known_certificates = set()
         if certificates_only:
             for filename in filenames:
-                certificate = self.__read_node_tls_certificate(os.path.join(self.certificates_dir, filename))
+                certificate = self.__read_node_tls_certificate(self.certificates_dir / filename)
                 known_certificates.add(certificate)
             return known_certificates
 
@@ -440,7 +385,7 @@ class LocalFileBasedNodeStorage(NodeStorage):
             known_nodes = set()
             invalid_metadata = []
             for filename in filenames:
-                metadata_path = os.path.join(self.metadata_dir, filename)
+                metadata_path = self.metadata_dir / filename
                 try:
                     node = self.__read_metadata(filepath=metadata_path)
                 except self.NodeStorageError:
@@ -453,52 +398,32 @@ class LocalFileBasedNodeStorage(NodeStorage):
             return known_nodes
 
     @validate_checksum_address
-    def get(self, checksum_address: str, federated_only: bool, certificate_only: bool = False):
+    def get(self, stamp: Union[SignatureStamp, str], federated_only: bool, certificate_only: bool = False):
         if certificate_only is True:
-            certificate = self.__read_node_tls_certificate(checksum_address=checksum_address)
+            certificate = self.__read_node_tls_certificate(stamp=stamp)
             return certificate
-        metadata_path = self.__generate_metadata_filepath(checksum_address=checksum_address)
+        metadata_path = self.__generate_metadata_filepath(stamp=stamp)
         node = self.__read_metadata(filepath=metadata_path)
         return node
 
-    def store_node_certificate(self, certificate: Certificate, force: bool = True):
-        certificate_filepath = self._write_tls_certificate(certificate=certificate, force=force)
+    def store_node_certificate(self, certificate: Certificate, port: int, force: bool = True):
+        certificate_filepath = self._write_tls_certificate(certificate=certificate, port=port, force=force)
         return certificate_filepath
 
-    def store_node_metadata(self, node, filepath: str = None) -> str:
-        address = node.checksum_address
-        filepath = self.__generate_metadata_filepath(checksum_address=address, metadata_dir=filepath)
+    def store_node_metadata(self, node, filepath: Optional[Path] = None) -> Path:
+        filepath = self.__generate_metadata_filepath(stamp=node.stamp, metadata_dir=filepath)
         self.__write_metadata(filepath=filepath, node=node)
         return filepath
 
-    @validate_checksum_address
-    def remove(self, checksum_address: str, metadata: bool = True, certificate: bool = True) -> None:
-
-        if metadata is True:
-            metadata_filepath = self.__generate_metadata_filepath(checksum_address=checksum_address)
-            os.remove(metadata_filepath)
-            self.log.debug("Deleted {} from the filesystem".format(checksum_address))
-
-        if certificate is True:
-            certificate_filepath = self.generate_certificate_filepath(checksum_address=checksum_address)
-            os.remove(certificate_filepath)
-            self.log.debug("Deleted {} from the filesystem".format(checksum_address))
-
-        return
-
     def clear(self, metadata: bool = True, certificates: bool = True) -> None:
         """Forget all stored nodes and certificates"""
 
-        def __destroy_dir_contents(path) -> None:
-            try:
-                paths_to_remove = os.listdir(path)
-            except FileNotFoundError:
+        def __destroy_dir_contents(path: Path) -> None:
+            if not path.is_dir():
                 return
-            else:
-                for file in paths_to_remove:
-                    file_path = os.path.join(path, file)
-                    if os.path.isfile(file_path):
-                        os.unlink(file_path)
+            for dir_item in path.iterdir():
+                if dir_item.is_file():
+                    dir_item.unlink()
 
         if metadata is True:
             __destroy_dir_contents(self.metadata_dir)
@@ -510,9 +435,9 @@ class LocalFileBasedNodeStorage(NodeStorage):
     def payload(self) -> dict:
         payload = {
             'storage_type': self._name,
-            'storage_root': self.root_dir,
-            'metadata_dir': self.metadata_dir,
-            'certificates_dir': self.certificates_dir
+            'storage_root': str(self.root_dir.absolute()),
+            'metadata_dir': str(self.metadata_dir.absolute()),
+            'certificates_dir': str(self.certificates_dir.absolute())
         }
         return payload
 
@@ -523,13 +448,15 @@ class LocalFileBasedNodeStorage(NodeStorage):
             raise cls.NodeStorageError("Wrong storage type. got {}".format(storage_type))
         del payload['storage_type']
 
+        payload = cast_paths_from(cls, payload)
+
         return cls(*args, **payload, **kwargs)
 
     def initialize(self):
         storage_dirs = (self.root_dir, self.metadata_dir, self.certificates_dir)
         for storage_dir in storage_dirs:
             try:
-                os.mkdir(storage_dir, mode=0o755)
+                storage_dir.mkdir(mode=0o755)
             except FileExistsError:
                 message = "There are pre-existing files at {}".format(self.root_dir)
                 self.log.info(message)
@@ -561,9 +488,9 @@ class TemporaryFileBasedNodeStorage(LocalFileBasedNodeStorage):
         self.root_dir = self.__temp_root_dir
 
         # Metadata
-        self.__temp_metadata_dir = str(Path(self.__temp_root_dir) / "metadata")
+        self.__temp_metadata_dir = Path(self.__temp_root_dir) / "metadata"
         self.metadata_dir = self.__temp_metadata_dir
 
         # Certificates
-        self.__temp_certificates_dir = str(Path(self.__temp_root_dir) / "certs")
+        self.__temp_certificates_dir = Path(self.__temp_root_dir) / "certs"
         self.certificates_dir = self.__temp_certificates_dir
