@@ -17,11 +17,12 @@
 
 
 import random
-import requests
 from ipaddress import ip_address
-from requests.exceptions import RequestException, HTTPError
 from typing import Union, Optional
 
+import requests
+from requests.exceptions import RequestException, HTTPError
+
 from nucypher.acumen.perception import FleetSensor
 from nucypher.blockchain.eth.registry import BaseContractRegistry
 from nucypher.config.storages import LocalFileBasedNodeStorage
@@ -34,7 +35,7 @@ class UnknownIPAddress(RuntimeError):
     pass
 
 
-class InvalidWorkerIP(RuntimeError):
+class InvalidOperatorIP(RuntimeError):
     """Raised when an Ursula is using an invalid IP address for it's server."""
 
 
@@ -59,10 +60,11 @@ RESERVED_IP_ADDRESSES = (
 IP_DETECTION_LOGGER = Logger('external-ip-detection')
 
 
-def validate_worker_ip(worker_ip: str) -> None:
-    if worker_ip in RESERVED_IP_ADDRESSES:
-        raise InvalidWorkerIP(f'{worker_ip} is not a valid or permitted worker IP address.  '
-                              f'Verify the rest_host is set to the external IPV4 address')
+def validate_operator_ip(ip: str) -> None:
+    if ip in RESERVED_IP_ADDRESSES:
+        raise InvalidOperatorIP(f"{ip} is not a valid or permitted operator IP address. "
+                                f"Verify the 'rest_host' configuration value is set to the "
+                                f"external IPV4 address")
 
 
 def _request(url: str, certificate=None) -> Union[str, None]:
@@ -114,18 +116,16 @@ def get_external_ip_from_default_teacher(network: str,
                                          log: Logger = IP_DETECTION_LOGGER
                                          ) -> Union[str, None]:
 
-    # Prevents circular import
+    # Prevents circular imports
     from nucypher.characters.lawful import Ursula
+    from nucypher.network.nodes import TEACHER_NODES
 
     if federated_only and registry:
         raise ValueError('Federated mode must not be true if registry is provided.')
+
     base_error = 'Cannot determine IP using default teacher'
-    try:
-        top_teacher_url = RestMiddleware.TEACHER_NODES[network][0]
-    except IndexError:
-        log.debug(f'{base_error}: No teacher available for network "{network}".')
-        return
-    except KeyError:
+
+    if network not in TEACHER_NODES:
         log.debug(f'{base_error}: Unknown network "{network}".')
         return
 
@@ -136,17 +136,26 @@ def get_external_ip_from_default_teacher(network: str,
     Ursula.set_federated_mode(federated_only)
     #####
 
-    try:
-        teacher = Ursula.from_teacher_uri(teacher_uri=top_teacher_url,
-                                          federated_only=federated_only,
-                                          min_stake=0)  # TODO: Handle customized min stake here.
-    except NodeSeemsToBeDown:
-        # Teacher is unreachable.  Move on.
+    external_ip = None
+    for teacher_uri in TEACHER_NODES[network]:
+        try:
+            teacher = Ursula.from_teacher_uri(teacher_uri=teacher_uri,
+                                              federated_only=federated_only,
+                                              min_stake=0)  # TODO: Handle customized min stake here.
+            # TODO: Pass registry here to verify stake (not essential here since it's a hardcoded node)
+            external_ip = _request_from_node(teacher=teacher)
+            # Found a reachable teacher, return from loop
+            if external_ip:
+                break
+        except NodeSeemsToBeDown:
+            # Teacher is unreachable, try next one
+            continue
+
+    if not external_ip:
+        log.debug(f'{base_error}: No teacher available for network "{network}".')
         return
 
-    # TODO: Pass registry here to verify stake (not essential here since it's a hardcoded node)
-    result = _request_from_node(teacher=teacher)
-    return result
+    return external_ip
 
 
 def get_external_ip_from_known_nodes(known_nodes: FleetSensor,
